﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Input;
using System.Windows;
using System.ComponentModel;

namespace WpfStrategy
{
	public class MainWindowViewModel : INotifyPropertyChanged
	{
		public IList<IVehicleCategory> Categories { get; private set; }

		public MainWindowViewModel()
		{
			Categories = new List<IVehicleCategory>();
			Categories.Add(new Car());
			Categories.Add(new Airplane());

			From = DateTime.Today;
			To = DateTime.Today;
			Category = Categories.First();
		}

		private DateTime _from;
		public DateTime From
		{
			get { return _from; }
			set
			{
				_from = value;
				OnPropertyChanged("From");
				OnPropertyChanged("CalculatedPrice");
			}
		}

		private DateTime _to;
		public DateTime To
		{
			get { return _to; }
			set
			{
				_to = value;
				OnPropertyChanged("CalculatedPrice");
			}
		}

		private IVehicleCategory _category;
		public IVehicleCategory Category
		{
			get { return _category; }
			set
			{
				_category = value;
				OnPropertyChanged("CalculatedPrice");
			}
		}

		public DateTime Today
		{
			get
			{
				return DateTime.Today;
			}
		}

public string CalculatedPrice
{
	get
	{
		return Category.GetPrice(To.AddDays(1) - From) + " $";
	}
}

		#region OnPropertyChanged implementation

		private void OnPropertyChanged(string prop)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(prop));
			}
		}

		public event PropertyChangedEventHandler PropertyChanged;

		#endregion
	}
}
